<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 */
function optionsframework_option_name() {
	// Change this to use your theme slug
	return 'neblue_options';
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'neblue'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// Test data
	$test_array = array(
		'one' => __( 'One', 'neblue' ),
		'two' => __( 'Two', 'neblue' ),
		'three' => __( 'Three', 'neblue' ),
		'four' => __( 'Four', 'neblue' ),
		'five' => __( 'Five', 'neblue' )
	);

	// Multicheck Array
	$multicheck_array = array(
		'one' => __( 'French Toast', 'neblue' ),
		'two' => __( 'Pancake', 'neblue' ),
		'three' => __( 'Omelette', 'neblue' ),
		'four' => __( 'Crepe', 'neblue' ),
		'five' => __( 'Waffle', 'neblue' )
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );

	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages( 'sort_column=post_parent,menu_order' );
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();

	$options[] = array(
		'name' => __( 'Header', 'neblue' ),
		'type' => 'heading'
	);
	// Favicon activate option
	$options[] = array(
		'name' 		=> __( 'Activate favicon', 'neblue' ),
		'desc' 		=> __( 'Check to activate favicon. Upload fav icon from below option', 'neblue' ),
		'id' 			=> 'neblue_activate_favicon',
		'std' 		=> '0',
		'type' 		=> 'checkbox'
	);

	// Fav icon upload option
	$options[] = array(
		'name' 	=> __( 'Upload favicon', 'neblue' ),
		'desc' 	=> __( 'Upload favicon for your site.', 'neblue' ),
		'id' 		=> 'neblue_favicon',
		'type' 	=> 'upload'
	);
	
	/*************************************************************************/
	
	$options[] = array(
		'name' => __( 'Design', 'neblue' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' 		=> __( 'Default layout', 'neblue' ),
		'desc' 		=> __( 'Select default layout. This layout will be reflected in whole site archives, search etc. The layout for a single post and page can be controlled from below options.', 'neblue' ),
		'id' 			=> 'neblue_default_layout',
		'std' 		=> 'right_sidebar',
		'type' 		=> 'images',
		'options' 	=> array(
								'right_sidebar' 	=> get_template_directory_uri() . '/images/right-sidebar.png',
								'left_sidebar' 		=> get_template_directory_uri() . '/images/left-sidebar.png',
								'no_sidebar_full_width'				=> get_template_directory_uri() . '/images/no-sidebar-full-width-layout.png',
							)
	);
	$options[] = array(
		'name' 		=> __( 'Default layout for pages only', 'neblue' ),
		'desc' 		=> __( 'Select default layout for pages. This layout will be reflected in all pages unless unique layout is set for specific page.', 'neblue' ),
		'id' 			=> 'neblue_pages_default_layout',
		'std' 		=> 'right_sidebar',
		'type' 		=> 'images',
		'options' 	=> array(
								'right_sidebar' 	=> get_template_directory_uri() . '/images/right-sidebar.png',
								'left_sidebar' 		=> get_template_directory_uri() . '/images/left-sidebar.png',
								'no_sidebar_full_width'				=> get_template_directory_uri() . '/images/no-sidebar-full-width-layout.png',
							)
	);
	$options[] = array(
		'name' 		=> __( 'Default layout for single posts only', 'neblue' ),
		'desc' 		=> __( 'Select default layout for single posts. This layout will be reflected in all single posts unless unique layout is set for specific post.', 'neblue' ),
		'id' 			=> 'neblue_single_posts_default_layout',
		'std' 		=> 'right_sidebar',
		'type' 		=> 'images',
		'options' 	=> array(
								'right_sidebar' 	=> get_template_directory_uri() . '/images/right-sidebar.png',
								'left_sidebar' 		=> get_template_directory_uri() . '/images/left-sidebar.png',
								'no_sidebar_full_width'				=> get_template_directory_uri() . '/images/no-sidebar-full-width-layout.png',
							)
	);

	/*************************************************************************/

	$options[] = array(
		'name' => __( 'Slider', 'neblue' ),
		'type' => 'heading'
	);

	// Slider activate option
	$options[] = array(
		'name' 		=> __( 'Activate slider', 'neblue' ),
		'desc' 		=> __( 'Check to activate slider.', 'neblue' ),
		'id' 			=> 'neblue_activate_slider',
		'std' 		=> '0',
		'type' 		=> 'checkbox'
	);

	// Slide options
	for( $i=1; $i<=4; $i++) {
		$options[] = array(
			'name' 	=>	sprintf( __( 'Image Upload #%1$s', 'neblue' ), $i ),
			'desc' 	=> __( 'Upload slider image.', 'neblue' ),
			'id' 		=> 'neblue_slider_image'.$i,
			'type' 	=> 'upload'
		);
		$options[] = array(
			'desc' 	=> __( 'Enter title for your slider.', 'neblue' ),
			'id' 		=> 'neblue_slider_title'.$i,
			'std' 	=> '',
			'type' 	=> 'text'
		);
		$options[] = array(
			'desc' 	=> __( 'Enter your slider description.', 'neblue' ),
			'id' 		=> 'neblue_slider_text'.$i,
			'std' 	=> '',
			'type' 	=> 'textarea'
		);
		$options[] = array(
			'desc' 	=> __( 'Enter link to redirect slider when clicked', 'neblue' ),
			'id' 		=> 'neblue_slider_link'.$i,
			'std' 	=> '',
			'type' 	=> 'text'
		);
	}
	/*************************************************************************/
	
	$options[] = array(
		'name' => __( 'Social', 'neblue' ),
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( 'Email Address', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_email',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Skype', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_skype',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Facebook', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_facebook',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Twitter', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_twitter',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Google Plus', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_google-plus',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'YouTube', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_youtube',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Instagram', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_instagram',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Pinterest', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_pinterest',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'LinkedIn', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_linkedin',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Tumblr', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_tumblr',
		'std' => '',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Flickr', 'neblue' ),
		'desc' => '',
		'id' => 'neblue_social_flickr',
		'std' => '',
		'type' => 'text'
	);
	
	return $options;
}

add_action( 'optionsframework_after','neblue_options_display_sidebar' );
/**
 * admin sidebar
 */
function neblue_options_display_sidebar() { 
?>
<div id="optionsframework-sidebar">
    <div class="metabox-holder">
        <div class="postbox">
            <h3><?php esc_attr_e( 'About NEBlue', 'neblue' ); ?></h3>
            <div class="inside">
                <div class="option-btn"><a class="btn demo" target="_blank" href="<?php echo esc_url( 'http://nethemes.com/demo/neblue/' ); ?>"><?php esc_attr_e( 'View Demo' , 'neblue' ); ?></a></div>
            </div>
        </div>
    </div>
</div>
<?php
}

?>